@@ -3,7 +3,7 @@ package Getopt::EX::Config;
 use v5.14;
 use warnings;
 
-our $VERSION = '1.0201';
+our $VERSION = '1.0202';
 
 our $REPLACE_UNDERSCORE = 1;
 
@@ -107,8 +107,9 @@ sub config {
 ######################################################################
 
 sub set {
-    my $c = shift;
+    my $obj = shift;
     while (my($k, $v) = splice @_, 0, 2) {
+	my $c = $obj;
 	my @names = split /\./, $k;
 	my $name = pop @names;
 	for (@names) {
@@ -171,7 +172,7 @@ Getopt::EX::Config - Getopt::EX module configuration interface
 
 =head1 VERSION
 
-Version 1.0201
+Version 1.0202
 
 =head1 DESCRIPTION
 
@@ -254,6 +255,54 @@ C<Getopt::Long> library.  The above code is equivalent to the
 following code.  See L<Getopt::Long/Storing options values in a hash>
 for detail.
 
+=head2 Nested Hash Configuration
+
+Config values can be hash references for structured configuration:
+
+    my $config = Getopt::EX::Config->new(
+        mode   => '',
+        hashed => { h3 => 0, h4 => 0, h5 => 0, h6 => 0 },
+    );
+
+Nested values can be accessed using dot notation in the C<config()>
+function:
+
+    example -Mfoo::config(hashed.h3=1,hashed.h4=1) ...
+
+    example -Mfoo --config hashed.h3=1 -- ...
+
+The dot notation navigates into nested hashes: C<hashed.h3=1> sets
+C<< $config->{hashed}{h3} >> to C<1>.  The intermediate key
+(C<hashed>) must exist as a hash reference, and the leaf key (C<h3>)
+must already exist in that hash.
+
+Hash options can also be defined as module private options using
+L<Getopt::Long> hash type (C<%>):
+
+    $config->deal_with($argv, "hashed=s%");
+
+This allows:
+
+    example -Mfoo --hashed h3=1 --hashed h4=1 -- ...
+
+Note that the C<Getopt::Long> hash type auto-vivifies keys, so
+C<--hashed h3=1> works even when C<h3> does not pre-exist in the hash.
+
+The dot notation and nested hash support are designed with future
+extensibility in mind.  For example, a configuration file under
+F<~/.config> could store module settings in YAML-like format:
+
+    # ~/.config/example/foo.yml
+    mode: dark
+    hashed:
+      h3: 1
+      h4: 1
+      h5: 1
+      h6: 1
+
+This would map naturally to the nested hash structure and dot notation
+already supported by this module.
+
     sub finalize {
         our($mod, $argv) = @_;
         $config->deal_with(
@@ -408,7 +457,7 @@ The following copyright notice applies to all the files provided in
 this distribution, including binary files, unless explicitly noted
 otherwise.
 
-Copyright ©︎ 2025 Kazumasa Utashiro
+Copyright ©︎ 2025-2026 Kazumasa Utashiro
 
 =head1 LICENSE
 
